<?php

namespace SM\Controller;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use SM\Service\SmPropostasAlimentacaoService;
use SM\Traits\TResponse;

class SmPropostaAlimentacaoController
{
    use TResponse;
    protected $propostaAlimentacao;

    public function __construct(SmPropostasAlimentacaoService $propostaAlimentacao)
    {
        $this->propostaAlimentacao = $propostaAlimentacao;
    }

    
    public function getPropostaAlimentacao(DTO\Request $request)
    {
        try {
            $data = $this->propostaAlimentacao->getPropostasAlimentacao($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    } 

    public function getEscopoFaturamentoProposta(DTO\Request $request)
    {
        try {
            $data = $this->propostaAlimentacao->getEscopoFaturamentoProposta($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    } 


    public function getTabServicosPropostas(DTO\Request $request)
    {
        try {
            $data = $this->propostaAlimentacao->getTabServicosPropostas($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function getCategorias(DTO\Request $request)
    {
        try {
            $data = $this->propostaInvestimentoService->getInvestimentoproposta($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTabFormacaoPreco(DTO\Request $request){

        try {
            $data = $this->propostaInvestimentoService->getTabFormacaoPreco($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getFormacaoPreco(DTO\Request $request){

        try {
            $data = $this->propostaInvestimentoService->getFormacaoPreco($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getComposicaoInvestimento(DTO\Request $request)
    {
        try {
            $data = $this->propostaInvestimentoService->getComposicaoInvestimento($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    // public function getComposicaoInvestimento(Request $request)
    // {
    //     try {
    //         $params = $request->getParameters();
    //         $this->propostaInvestimentoService->getComposicaoInvestimento($params);
    //     } catch (\Exception $ex) {
    //         $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
    //     }
    // }

    public function saveInvestimentos(Request $request)
    {
        try {
            $params = $request->getParameters();
            $this->propostaInvestimentoService->saveInvestimentos($params);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    
    public function saveComposicaoInvest(DTO\Request $request)
    {
        try {
            $data = $this->propostaInvestimentoService->saveComposicaoServicos($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveRelacFormInvest(DTO\Request $request)
    {
        try {
            $data = $this->propostaInvestimentoService->saveRelacFormInvest($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }


    // public function saveComposicaoInvest(Request $request)
    // {
    //     try {
    //         $params = $request->getParameters();
    //         $this->propostaInvestimentoService->saveComposicaoServicos($params);
    //     } catch (\Exception $ex) {
    //         $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
    //     }
    // }
   
    // public function saveInvestimentos(DTO\Request $request)
    // {
    //     try {
    //         $data = $this->propostaInvestimentoService->saveInvestimentos($request->getParameters());
    //         $this->sendResponse($data, 200);
    //     } catch (\Exception $ex) {
    //         $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
    //     }
    // }

    // public function getInvestimentoproposta(Request $request) 
    // {
    //     try {
    //         $parameters = $request->getParameters();
    //         $data = $this->propostaInvestimentoService->getInvestimentoproposta($parameters);
    //         $this->sendResponse($data, 200);
    //     } catch (\Exception $ex) {
    //         $this->sendResponse(["error" => $ex->getMessage(), "code" => $ex->getCode()], 500);
    //     }
    // }   

    public function getTabComposicoesProposta(Request $request) 
    {
        try {
            $parameters = $request->getParameters();
            $data = $this->propostaInvestimentoService->getTabComposicoesProposta($parameters);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(["error" => $ex->getMessage(), "code" => $ex->getCode()], 500);
        }
    }    

    public function saveComposicaoServicoTab(Request $request) 
    {
        try {
            $params = $request->getParameters();
            $data = $this->propostaInvestimentoService->saveComposicaoServicoTab($params);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(["error" => $ex->getMessage(), "code" => $ex->getCode()], 500);
        }
    }    

    public function getComposicoesProposta(Request $request) 
    {
        try {
            $parameters = $request->getParameters();
            $data = $this->propostaInvestimentoService->getComposicoesProposta();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(["error" => $ex->getMessage(), "code" => $ex->getCode()], 500);
        }
    }  

    public function saveTabImposto(DTO\Request $request)
    {
        try {
            $data = $this->propostaInvestimentoService->saveTabImposto($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteInvest(Request $request)
    {
        try {
            $data = $this->propostaInvestimentoService->deleteInvest($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(["error" => $ex->getMessage(), "code" => $ex->getCode()], 500);
        }
    }

    public function deleteComposi(Request $request)
    {
        try {
            $data = $this->propostaInvestimentoService->deleteComposi($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(["error" => $ex->getMessage(), "code" => $ex->getCode()], 500);
        }
    }

    public function deleteFormPreco(Request $request)
    {
        try {
            $data = $this->propostaInvestimentoService->deleteFormPreco($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(["error" => $ex->getMessage(), "code" => $ex->getCode()], 500);
        }
    }

    
    /**
     * Deleta alguns servicos do imposto ou o imposto inteiro
    **/
    // public function deleteImposto(Request\Row $request, Response $response){
    //     try{
    //         $row = $request->getRow();
    //         $cdimposto     = $row["CDIMPOSTO"];
    //         $nrimpostoserv = $row["NRIMPOSTOSERV"];
    //         $this->propostaInvestimentoService->deleteImposto($cdimposto, $nrimpostoserv);
    //     } catch(\Exception $e){
    //         $response->setError(new Response\Error($e->getMessage(), $e->getCode()));        
    //     }
    // }
    /**
     * Salva a edição de um imposto relacionado a um serviço
    **/
}