<?php
namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;


class SmPropostasImpostosFactory
{

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getImpostoproposta()
    {
        $sql = "SELECT 
                    rel.NRIMPOSTOSERV, 
                    rel.NRCOMPSERVICO, 
                    rel.CDIMPOSTO, 
                    rel.VRPRECIMPOSTO,
                    imp.NMIMPOSTO, 
                    rel.IDATIVO, 
                    rel.NRORG 
                FROM FCT_RELACIMPOSTOSERV rel
                LEFT JOIN IMPOSTO imp ON rel.CDIMPOSTO = imp.CDIMPOSTO";
    
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getComposicoesProposta($params)
    {
        $sql = "SELECT FCT_RELACIMPOSTOSERV.NRIMPOSTOSERV,
            FCT_RELACIMPOSTOSERV.NRCOMPSERVICO,
            FCT_RELACIMPOSTOSERV.CDIMPOSTO,
            FCT_COMPSERVICO.NMCOMPSERVICO,
            FCT_COMPSERVICO.NRCOMPSERVICOPAI,
            COMP_PAI.NMCOMPSERVICO AS NMCOMPSERVICOPAI,
            FCT_RELACIMPOSTOSERV.NRORG,
            FCT_RELACIMPOSTOSERV.DTINCLUSAO,
            FCT_RELACIMPOSTOSERV.NRORGINCLUSAO,
            FCT_RELACIMPOSTOSERV.CDOPERINCLUSAO,
            OPINC.NMOPERADOR AS NMOPERINCLUSAO,
            FCT_RELACIMPOSTOSERV.DTULTATU,
            FCT_RELACIMPOSTOSERV.NRORGULTATU,
            FCT_RELACIMPOSTOSERV.CDOPERULTATU,
            OPATU.NMOPERADOR AS NMOPERULTATU,
            FCT_RELACIMPOSTOSERV.IDATIVO
        FROM
            FCT_RELACIMPOSTOSERV
        INNER JOIN FCT_COMPSERVICO ON FCT_RELACIMPOSTOSERV.NRCOMPSERVICO = FCT_COMPSERVICO.NRCOMPSERVICO
        AND FCT_RELACIMPOSTOSERV.NRORG = FCT_COMPSERVICO.NRORG
        LEFT JOIN FCT_COMPSERVICO COMP_PAI ON FCT_COMPSERVICO.NRCOMPSERVICOPAI = COMP_PAI.NRCOMPSERVICO
        AND FCT_COMPSERVICO.NRORG = COMP_PAI.NRORG
        LEFT JOIN OPERADOR OPINC ON FCT_RELACIMPOSTOSERV.CDOPERINCLUSAO = OPINC.CDOPERADOR
        AND FCT_RELACIMPOSTOSERV.NRORG = OPINC.NRORG
        LEFT JOIN OPERADOR OPATU ON FCT_RELACIMPOSTOSERV.CDOPERULTATU = OPATU.CDOPERADOR
        AND FCT_RELACIMPOSTOSERV.NRORG = OPATU.NRORG";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function saveTabImposto(array $params)
{
    $sql = "INSERT INTO FCT_RELACIMPOSTOSERV (
        NRIMPOSTOSERV, CDIMPOSTO, VRPRECIMPOSTO, NRORG, 
        DTINCLUSAO, IDATIVO, NRORGINCLUSAO, CDOPERINCLUSAO
    ) VALUES (
        :NRIMPOSTOSERV, :CDIMPOSTO, :VRPRECIMPOSTO, :NRORG, 
        SYSDATE, :IDATIVO, :NRORGINCLUSAO, :CDOPERINCLUSAO
    )";

    $this->connection->executeStatement($sql, $params);
}

public function saveTabComposicao(array $params)
{
    $sql = "INSERT INTO FCT_RELACIMPOSTOSERV (
        NRIMPOSTOSERV, NRORG, NRCOMPSERVICO, CDIMPOSTO, DTINCLUSAO, IDATIVO, NRORGINCLUSAO, CDOPERINCLUSAO
    ) VALUES (
        :NRIMPOSTOSERV, :NRORG, :NRCOMPSERVICO, :CDIMPOSTO, SYSDATE, :IDATIVO, :NRORGINCLUSAO, :CDOPERINCLUSAO
    )";

    $this->connection->executeStatement($sql, $params);
}
public function updateTabImposto(array $params)
{
    $sql = "UPDATE FCT_RELACIMPOSTOSERV SET 
            CDIMPOSTO = :CDIMPOSTO,
            VRPRECIMPOSTO = :VRPRECIMPOSTO,
            NRORG = :NRORG,
            NRORGULTATU = :NRORGULTATU,
            NRORGINCLUSAO = :NRORGINCLUSAO,
            CDOPERINCLUSAO = :CDOPERINCLUSAO,
            CDOPERULTATU = :CDOPERULTATU,
            IDATIVO = :IDATIVO
        WHERE NRIMPOSTOSERV = :NRIMPOSTOSERV";

    $this->connection->executeStatement($sql, $params);
}

public function saveModalAddProposalModelTabComposicoes($params)
{
    $sql = "INSERT INTO FCT_RELORCAMODCOMPOSICAO 
                   (NRRELORCAMODCOMP,
                    NRORCAMENTOMODELO,
                    NRCOMPSERVICO,
                    IDATIVO,
                    NRORG,
                    CDOPERINCLUSAO,
                    CDOPERULTATU,
                    DTINCLUSAO)

            VALUES (:NRRELORCAMODCOMP,
                    :NRORCAMENTOMODELO,
                    :NRCOMPSERVICO,
                    :IDATIVO,
                    :NRORG,
                    :CDOPERINCLUSAO,
                    :CDOPERULTATU,
                    SYSDATE)";
    $this->connection->executeStatement($sql, $params);
}

public function verificaSeExiste($param)
{
    $sql = "SELECT NRCOMPSERVICO FROM FCT_RELACIMPOSTOSERV WHERE NRCOMPSERVICO = :NRCOMPSERVICO";
    $result = $this->connection->fetchOne($sql, ['NRCOMPSERVICO' => $param['NRCOMPSERVICO']]);

    return $result ?: '';
}

public function updateTabComposicao(array $params)
{
    $sql = "UPDATE FCT_RELACIMPOSTOSERV SET 
            CDIMPOSTO = :CDIMPOSTO,
            NRCOMPSERVICO = :NRCOMPSERVICO,
            NRORG = :NRORG,
            NRORGULTATU = :NRORGULTATU,
            NRORGINCLUSAO = :NRORGINCLUSAO,
            CDOPERINCLUSAO = :CDOPERINCLUSAO,
            CDOPERULTATU = :CDOPERULTATU,
            IDATIVO = :IDATIVO
        WHERE NRIMPOSTOSERV = :NRIMPOSTOSERV";

    $this->connection->executeStatement($sql, $params);
}


public function deleteImposto($parametros)
    {
        $sql = "DELETE FROM  FCT_RELACIMPOSTOSERV
                WHERE  NRIMPOSTOSERV IN (".$parametros.")";
        
        $this->connection->executeStatement($sql);
    }
    
    public function deleteImpostoComposicaoServ($parametros)
    {
        $sql = "DELETE FROM  FCT_RELACIMPOSTOSERV
                WHERE NRCOMPSERVICO IN (".$parametros.")";
        
        $this->connection->executeStatement($sql);
    }
}