import {
    Http, IEventParam, Metadata,
} from '@zeedhi/core';
import {
    Button,
    DialogService, Form, LoadingService, Modal, ModalService, Select, SelectMultiple, Tabs, Textarea, TextInput,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class SmPropostasAlimentacaoController {
    public tekgridVisivel: boolean = true;

    public currentRow: any = {};

    public viewTab: boolean = false;

    public tituloHeaderFrameOperadoresEquipes: String = '';

    private ModalFiltro!: Modal;

    get textFrame() {
        return this.currentRow.NRORCAMENTO;
    }

    get formVisivel() {
        return !this.tekgridVisivel;
    }

    get tabInvisivel() {
        return this.currentRow.IDTPMEDIDASERV !== 'F';
    }

    public async createModalFiltroElemento() {
        this.ModalFiltro = await ModalService.createFromJson('/investimentos/SmpropostasFiltro', true);
        // this.openModalFiltroElemento();
    }

    public openModalFiltroElemento() {
        this.ModalFiltro.show();
        setTimeout(() => {
            Metadata.getInstance<Select>('filtro-DSINVESTIMENTO').value = this.currentRow.DSINVESTIMENTO;
            Metadata.getInstance<Select>('filtro-categoria').value = this.currentRow.CDCATINVEST;
        }, 200);
    }

    public recarregarTabs() {
        const voltarButton = Metadata.getInstance<Button>('buttonContinue-4');
        const avancarButton = Metadata.getInstance<Button>('buttonContinue-3');
        const salvarButton = Metadata.getInstance<Button>('buttonContinue-2');

        voltarButton.isVisible = this.activeStep !== 1;

        if (this.activeStep === 9) {
            salvarButton.isVisible = true;
            avancarButton.isVisible = false;
        } else {
            salvarButton.isVisible = false;
            avancarButton.isVisible = true;
        }
    }

    public changeEscopoFaturamento({ component }: IEventParam<Select>) {
        const escopoFaturamento = Metadata.getInstance<Select>('select-escopo-fatura');

        if (component.value) {
            escopoFaturamento.disabled = false;
            escopoFaturamento.datasource.setFilter({
                NRORCAMENTOMODELO: component.value,
            });
        } else {
            escopoFaturamento.value = null;
            escopoFaturamento.disabled = true;
        }
    }

    public closeModalFiltroElemento() {
        this.ModalFiltro.hide();
    }

    public eventFilter({ event }: any) {
        this.openModalFiltroElemento();
        event.preventDefault();
    }

    public addNewRow({ component }: IEventParam<TekGrid>) {
        const newId = 0;
        component.addNewRow({ NRINVESTIMENTO: newId, IDATIVO: 'S' }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`DSINVESTIMENTO_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    public addNewRowComposi({ component }: IEventParam<TekGrid>) {
        const newId = 0;
        component.addNewRow({ NRRELACSERVINVEST: newId, IDATIVO: 'S' }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NRCOMPSERVICO_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    public addNewRowFormPreco({ component }: IEventParam<TekGrid>) {
        const newId = 0;
        component.addNewRow({ NRRELACFORMINVEST: newId, IDATIVO: 'S' }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NRFORMPRECOSERVICO_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    private clickTimeout: any = null;

    private clicks: number = 0;

    public rowClick({ row, component }: any) {
        this.clicks += 1;

        if (this.clicks === 1) {
            this.clickTimeout = setTimeout(() => {
                if (!component.editing) {
                    this.currentRow = row;
                    this.tekgridVisivel = false;

                    const tabs = Metadata.getInstance<Tabs>('tabsInformation');

                    if (tabs.activeTab !== 0) {
                        tabs.activeTab = 0;
                    }

                    setTimeout(() => {
                        this.setFilterOperadorEquipe();
                        this.setFilterFormpreco();
                    }, 100);
                }

                this.clicks = 0;
            }, 300);
        } else if (this.clicks === 2) {
            clearTimeout(this.clickTimeout);
            component.editing(row);
            this.clicks = 0;
        }
    }

    public setFilterFormpreco() {
        const gridComposicao = Metadata.getInstance<TekGrid>('tab-formPreco');
        gridComposicao.datasource.setFilter({
            NRINVESTIMENTO: this.currentRow.NRINVESTIMENTO,
        });
    }

    public abrirFrameAdd() {
        this.tekgridVisivel = false;
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        tabs.activeTab = 0;
    }

    public abrirFrame() {
        this.carregarDadosEscopoFaturamentoTabEscopoFaturamento();
        this.tekgridVisivel = false;
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        tabs.activeTab = 0;
    }

    public carregarDadosEscopoFaturamentoTabEscopoFaturamento() {
        console.warn(this.currentRow);
        Metadata.getInstance<Select>('NRORCAMENTOMODELO').value = this.currentRow.NRORCAMENTOMODELO;
        Metadata.getInstance<Select>('select-escopo-fatura').value = this.currentRow.NRTIPOORCAMENTO;
        Metadata.getInstance<TextInput>('NRCALCFORMPRECSERV').value = this.currentRow.NRCALCFORMPRECSERV;
        Metadata.getInstance<TextInput>('NRVERSAOORCAMENTO').value = this.currentRow.NRVERSAOORCAMENTO;
        Metadata.getInstance<TextInput>('DTREFORCAMENTO').value = this.currentRow.DTREFORCAMENTO || new Date().toISOString().split('T')[0];
        Metadata.getInstance<Select>('IDSITUACAOORCAMENTO').value = this.currentRow.IDSITUACAOORCAMENTO;
        Metadata.getInstance<TextInput>('VRORCAMENTO').value = this.currentRow.VRORCAMENTO;
        Metadata.getInstance<TextInput>('DTACEITEORCA').value = this.currentRow.DTACEITEORCA;
        Metadata.getInstance<Select>('CDOPERRESPONSAVEL').value = this.currentRow.CDOPERRESPONSAVEL;
        Metadata.getInstance<SelectMultiple>('NRPARCNEGOCIO').value = this.currentRow.NRPARCNEGOCIO;
        Metadata.getInstance<TextInput>('NRINSCRICAOPARC').value = this.currentRow.NRINSCRICAOPARC;
        Metadata.getInstance<TextInput>('VRPERCMARKUP').value = this.currentRow.VRPERCMARKUP;
        Metadata.getInstance<SelectMultiple>('DSREFERENCIAORCA').value = this.currentRow.DSREFERENCIAORCA;
        Metadata.getInstance<TextInput>('QTDIASVALIDADE').value = this.currentRow.QTDIASVALIDADE;
        Metadata.getInstance<TextInput>('DTVALIDADE').value = this.currentRow.DTVALIDADE;
        Metadata.getInstance<TextInput>('NRDIASCARENCIA').value = this.currentRow.NRDIASCARENCIA;
        Metadata.getInstance<Textarea>('DSOBSERVACAOORCA').value = this.currentRow.DSOBSERVACAOORCA;
    }

    public filtrarElemento() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-investimento');
        const form = Metadata.getInstance<Form>('form-filter');

        const selectedInvestimentos = Metadata.getInstance<SelectMultiple>('filtro-DSINVESTIMENTO').value;
        const selectedCategorias = Metadata.getInstance<SelectMultiple>('filtro-categoria').value;

        const investimentosSelecionados = Metadata.getInstance<SelectMultiple>('filtro-DSINVESTIMENTO')
            .datasource.data
            .filter((item: any) => selectedInvestimentos.includes(item.NRINVESTIMENTO))
            .map((item: any) => item.DSINVESTIMENTO);

        this.currentRow.CDCATINVEST = selectedCategorias;
        this.currentRow.DSINVESTIMENTO = investimentosSelecionados;

        if (Utilities.validateForm(form)) {
            grid.datasource.setFilter({
                CDCATINVEST: this.currentRow.CDCATINVEST,
                DSINVESTIMENTO: this.currentRow.DSINVESTIMENTO,
            });
            this.ModalFiltro.hide();
        }
    }

    public activeStep: number = 1;

    public steps: number = 9;

    public step: number = 1;

    /* eslint-disable */

    public nextStep() {
        if (this.activeStep < this.steps) {
            this.activeStep++;
        }
        this.recarregarTabs();
    }

    public backStep() {
        if (this.activeStep > 1) {
            this.activeStep--;
        }
        this.recarregarTabs();
    }

    /* eslint-enable */

    public limparCampos() {
        Metadata.getInstance<Form>('form-filter').clearForm();
    }

    public verificaTab() {
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        const tabAtiva = tabs.activeTab;

        if (tabs.tabs[tabAtiva].name === 'tab_variacao') {
            this.carregarDadosAbaVariacao();
        }
    }

    public voltarTekGrid() {
        this.tekgridVisivel = true;
    }

    public setFilterOperadorEquipe() {
        const gridOperador = Metadata.getInstance<TekGrid>('tab-composi');
        gridOperador.datasource.setFilter({
            NRINVESTIMENTO: this.currentRow.NRINVESTIMENTO,
        });
    }

    public investimentoTabComposicoes() {
        console.warn('entrou');
        const grid = Metadata.getInstance<TekGrid>('tab-composi');
        grid.datasource.setFilter({
            NRINVESTIMENTO: this.currentRow.NRINVESTIMENTO,
        });
        console.warn('ede');
    }

    public carregarDadosAbaVariacao() {
        const cdtpmedidaserv = this.currentRow.NRIMPOSTOSERV;
        try {
            const grid = Metadata.getInstance<TekGrid>('tabcomposi');
            grid.datasource.setFilter({
                CDIMPOSTO: cdtpmedidaserv,
            });
        } catch (e) {
            // console.log(e);
        }
    }

    public carregarDadosAbaTipoMedida() {
        Metadata.getInstance<Select>('CDIMPOSTO').value = this.currentRow.CDIMPOSTO;
        Metadata.getInstance<TextInput>('VRPRECIMPOSTO').value = this.currentRow.VRPRECIMPOSTO;
        Metadata.getInstance<Select>('NRCOMPSERVICO').value = this.currentRow.NRCOMPSERVICO;
    }

    public savePropostaAlimentacao() {
        const form = Metadata.getInstance<Form>('form-modelo-documento-cda');
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-propostas-alimentacao');

        if (Utilities.validateForm(form)) {
            LoadingService.show();
            Http.post('/savePropostaAlimentacao', {
                NRORCAMENTO: Metadata.getInstance<TextInput>('NRORCAMENTO').value = this.currentRow.NRORCAMENTO,
                NRVERSAOORCAMENTO: Metadata.getInstance<TextInput>('NRVERSAOORCAMENTO').value,
                IDSITUACAOORCAMENTO: Metadata.getInstance<Select>('IDSITUACAOORCAMENTO').value,
                DTREFORCAMENTO: Metadata.getInstance<TextInput>('DTREFORCAMENTO').value,
                NMORCAMENTOMODELO: Metadata.getInstance<TextInput>('NMORCAMENTOMODELO').value,
                NRPARCNEGOCIO: Metadata.getInstance<TextInput>('NRPARCNEGOCIO').value,
                VRORCAMENTO: Metadata.getInstance<TextInput>('VRORCAMENTO').value,

                DSDESPESA: Metadata.getInstance<TextInput>('DSDESPESA').value,
                CDPERIODO: Metadata.getInstance<Select>('CDPERIODO').value,
                VRDESPESA: Metadata.getInstance<TextInput>('VRDESPESA').value,
                CDIMPOSTO: Metadata.getInstance<Select>('CDIMPOSTO').value,
                VRPRECIMPOSTO: Metadata.getInstance<TextInput>('VRPRECIMPOSTO').value,
                NRCALCFORMPRECSERV: Metadata.getInstance<TextInput>('NRCALCFORMPRECSERV').value,
                // NRVERSAOORCAMENTO: Metadata.getInstance<TextInput>('NRVERSAOORCAMENTO').value,
                // DTREFORCAMENTO: Metadata.getInstance<TextInput>('DTREFORCAMENTO').value,
                // IDSITUACAOORCAMENTO: Metadata.getInstance<Select>('IDSITUACAOORCAMENTO').value,
                // VRORCAMENTO: Metadata.getInstance<TextInput>('VRORCAMENTO').value,
                DTACEITEORCA: Metadata.getInstance<TextInput>('DTACEITEORCA').value,
                CDOPERRESPONSAVEL: Metadata.getInstance<Select>('CDOPERRESPONSAVEL').value,
                NRINSCRICAOPARC: Metadata.getInstance<TextInput>('NRINSCRICAOPARC').value,
                VRPERCMARKUP: Metadata.getInstance<TextInput>('VRPERCMARKUP').value,
                DSREFERENCIAORCA: Metadata.getInstance<SelectMultiple>('DSREFERENCIAORCA').value,
                QTDIASVALIDADE: Metadata.getInstance<TextInput>('QTDIASVALIDADE').value,
                DTVALIDADE: Metadata.getInstance<TextInput>('DTVALIDADE').value,
                NRDIASCARENCIA: Metadata.getInstance<TextInput>('NRDIASCARENCIA').value,
            }).then(() => {
                grid.datasource.get();
                this.voltarTekGrid();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    /* eslint-disable */

    public saveComposiServ({ component, event }: IEventParam<TekGrid>, nr: any) {
        event?.preventDefault();
        if (Utilities.validateGrid(component)) {
            LoadingService.show();
            const editedRows = component.getEditedRows().map(row => ({
                ...row,
                NRINVESTIMENTO: this.currentRow.NRINVESTIMENTO,
            }));
            const sendObject = {
                DRG: editedRows
            };
            Http.post('/saveComposicaoInvest', sendObject)
                .then(() => {
                    component.datasource.get();
                    Utilities.showSuccessMessage();
                })
                .catch((error: any) => {
                    Utilities.showErrorMessage(error);
                })
                .finally(() => {
                    component.cancelEditedRows();
                    LoadingService.hide();
                });
        }
    }

    public saveFormPreco({ component, event }: IEventParam<TekGrid>, nr: any) {
        event?.preventDefault();
        if (Utilities.validateGrid(component)) {
            LoadingService.show();
            const editedRows = component.getEditedRows().map(row => ({
                ...row,
                NRINVESTIMENTO: this.currentRow.NRINVESTIMENTO,
            }));
            const sendObject = {
                DRG: editedRows
            };
            Http.post('/saveRelacFormInvest', sendObject)
                .then(() => {
                    component.datasource.get();
                    Utilities.showSuccessMessage();
                })
                .catch((error: any) => {
                    Utilities.showErrorMessage(error);
                })
                .finally(() => {
                    component.cancelEditedRows();
                    LoadingService.hide();
                });
        }
    }

    /* eslint-enable */

    public showDialogWithButtonsGrid({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'SmPropostasInvestimentosController.deleteInvest');
    }

    public deleteInvest() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-investimento');
        LoadingService.show();
        Http.post('/deleteInvest', {
            NRS: grid.selectedRows.map((element: any) => element.NRINVESTIMENTO),
        }).then(() => {
            grid.selectedRows = [];
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            DialogService.hide();
        });
    }

    public showDialogBeforeDelete({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'SmPropostasInvestimentosController.deleteComposi');
    }

    public deleteComposi() {
        const grid = Metadata.getInstance<TekGrid>('tab-composi');
        LoadingService.show();
        Http.post('/deleteComposi', {
            NRS: grid.selectedRows.map((element: any) => element.NRRELACSERVINVEST),
        }).then(() => {
            grid.selectedRows = [];
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            DialogService.hide();
        });
    }

    public showDialogBeforeDeleteForm({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'SmPropostasInvestimentosController.deleteFormImposto');
    }

    public deleteFormImposto() {
        const grid = Metadata.getInstance<TekGrid>('tab-formPreco');
        LoadingService.show();
        Http.post('/deleteFormPreco', {
            NRS: grid.selectedRows.map((element: any) => element.NRRELACFORMINVEST),
        }).then(() => {
            grid.selectedRows = [];
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            DialogService.hide();
        });
    }
}
