import {
    Http, IEventParam, Metadata,
} from '@zeedhi/core';
import {
    DialogService, LoadingService, Select, Tabs, TextInput,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class SmPropostasInvestimentosController {
    public tekgridVisivel: boolean = true;

    public currentRow: any = {};

    public viewTab: boolean = false;

    public tituloHeaderFrameOperadoresEquipes: String = '';

    get textFrame() {
        return this.currentRow.DSINVESTIMENTO;
    }

    get formVisivel() {
        return !this.tekgridVisivel;
    }

    get tabInvisivel() {
        return this.currentRow.IDTPMEDIDASERV !== 'F';
    }

    public addNewRow({ component }: IEventParam<TekGrid>) {
        const newId = 0;
        component.addNewRow({ NRINVESTIMENTO: newId, IDATIVO: 'S' }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`DSINVESTIMENTO_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    public addNewRowComposi({ component }: IEventParam<TekGrid>) {
        const newId = 0;
        component.addNewRow({ NRRELACSERVINVEST: newId, IDATIVO: 'S' }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NRCOMPSERVICO_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    public addNewRowFormPreco({ component }: IEventParam<TekGrid>) {
        const newId = 0;
        component.addNewRow({ NRRELACFORMINVEST: newId, IDATIVO: 'S' }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NRFORMPRECOSERVICO_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    private clickTimeout: any = null;

    private clicks: number = 0;

    public rowClick({ row, component }: any) {
        this.clicks += 1;
    
        if (this.clicks === 1) {
            this.clickTimeout = setTimeout(() => {
                if (!component.editing) {
                    this.currentRow = row;
                    this.tekgridVisivel = false;
    
                    const tabs = Metadata.getInstance<Tabs>('tabsInformation');

                    if (tabs.activeTab !== 0) {
                        tabs.activeTab = 0;
                    }
                    setTimeout(() => {
                        this.setFilterOperadorEquipe();
                        this.setFilterFormpreco();
                    }, 100);
                }
    
                this.clicks = 0;
            }, 300);
        } else if (this.clicks === 2) {
            clearTimeout(this.clickTimeout);
            component.editing(row);
            this.clicks = 0;
        }
    }

    public setFilterFormpreco() {
        const gridComposicao = Metadata.getInstance<TekGrid>('tab-formPreco');
        gridComposicao.datasource.setFilter({
            NRINVESTIMENTO: this.currentRow.NRINVESTIMENTO,
        });
    }

    public abrirFrameAdd() {
        this.tekgridVisivel = false;
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        tabs.activeTab = 0;
        Metadata.getInstance<Select>('NRCOMPSERVICO').value = null;
    }

    public verificaTab() {
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        const tabAtiva = tabs.activeTab;

        if (tabs.tabs[tabAtiva].name === 'tab_variacao') {
            this.carregarDadosAbaVariacao();
        }
    }

    public voltarTekGrid() {
        this.tekgridVisivel = true;
    }

    public setFilterOperadorEquipe() {
        const gridOperador = Metadata.getInstance<TekGrid>('tab-composi');
        gridOperador.datasource.setFilter({
            NRINVESTIMENTO: this.currentRow.NRINVESTIMENTO,
        });
    }

    public investimentoTabComposicoes() {
        const grid = Metadata.getInstance<TekGrid>('tab-composi');
        grid.datasource.setFilter({
            NRINVESTIMENTO: this.currentRow.NRINVESTIMENTO,
        });
    }

    public carregarDadosAbaVariacao() {
        const cdtpmedidaserv = this.currentRow.NRIMPOSTOSERV;
        try {
            const grid = Metadata.getInstance<TekGrid>('tabcomposi');
            grid.datasource.setFilter({
                CDIMPOSTO: cdtpmedidaserv,
            });
        } catch (e) {
            // console.log(e);
        }
    }

    public carregarDadosAbaTipoMedida() {
        Metadata.getInstance<Select>('CDIMPOSTO').value = this.currentRow.CDIMPOSTO;
        Metadata.getInstance<TextInput>('VRPRECIMPOSTO').value = this.currentRow.VRPRECIMPOSTO;
        Metadata.getInstance<Select>('NRCOMPSERVICO').value = this.currentRow.NRCOMPSERVICO;
    }

    public saveInvestimentos({ component, event }: IEventParam<TekGrid>) {
        event?.preventDefault();
        if (Utilities.validateGrid(component)) {
            LoadingService.show();
            const sendObject = {
                DRG: component.getEditedRows(),
            };
            Http.post('/saveInvestimentos', sendObject).then(() => {
                component.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
                LoadingService.hide();
            }).finally(() => {
                component.cancelEditedRows();
                LoadingService.hide();
            });
        }
    }
    /* eslint-disable */

    public saveComposiServ({ component, event }: IEventParam<TekGrid>, nr: any) {
        event?.preventDefault();
        if (Utilities.validateGrid(component)) {
            LoadingService.show();
            const editedRows = component.getEditedRows().map(row => ({
                ...row,
                NRINVESTIMENTO: this.currentRow.NRINVESTIMENTO,
            }));
            const sendObject = {
                DRG: editedRows
            };
            Http.post('/saveComposicaoInvest', sendObject)
                .then(() => {
                    component.datasource.get();
                    Utilities.showSuccessMessage();
                })
                .catch((error: any) => {
                    Utilities.showErrorMessage(error);
                })
                .finally(() => {
                    component.cancelEditedRows();
                    LoadingService.hide();
                });
        }
    }

    public saveFormPreco({ component, event }: IEventParam<TekGrid>, nr: any) {
        event?.preventDefault();
        if (Utilities.validateGrid(component)) {
            LoadingService.show();
            const editedRows = component.getEditedRows().map(row => ({
                ...row,
                NRINVESTIMENTO: this.currentRow.NRINVESTIMENTO,
            }));
            const sendObject = {
                DRG: editedRows
            };
            Http.post('/saveRelacFormInvest', sendObject)
                .then(() => {
                    component.datasource.get();
                    Utilities.showSuccessMessage();
                })
                .catch((error: any) => {
                    Utilities.showErrorMessage(error);
                })
                .finally(() => {
                    component.cancelEditedRows();
                    LoadingService.hide();
                });
        }
    }

    /* eslint-enable */

    public showDialogWithButtonsGrid({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'SmPropostasInvestimentosController.deleteInvest');
    }

    public deleteInvest() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-investimento');
        LoadingService.show();
        Http.post('/deleteInvest', {
            NRS: grid.selectedRows.map((element: any) => element.NRINVESTIMENTO),
        }).then(() => {
            grid.selectedRows = [];
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            DialogService.hide();
        });
    }

    public showDialogBeforeDelete({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'SmPropostasInvestimentosController.deleteComposi');
    }

    public deleteComposi() {
        const grid = Metadata.getInstance<TekGrid>('tab-composi');
        LoadingService.show();
        Http.post('/deleteComposi', {
            NRS: grid.selectedRows.map((element: any) => element.NRRELACSERVINVEST),
        }).then(() => {
            grid.selectedRows = [];
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            DialogService.hide();
        });
    }

    public showDialogBeforeDeleteForm({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'SmPropostasInvestimentosController.deleteFormImposto');
    }

    public deleteFormImposto() {
        const grid = Metadata.getInstance<TekGrid>('tab-formPreco');
        LoadingService.show();
        Http.post('/deleteFormPreco', {
            NRS: grid.selectedRows.map((element: any) => element.NRRELACFORMINVEST),
        }).then(() => {
            grid.selectedRows = [];
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            DialogService.hide();
        });
    }
}
